pub struct SpecializationPriority(/* private fields */);Expand description
Impls with higher priority take precedence over impls with lower priority (if both apply to the same types). Impls with equal priority should never apply to the same set of input types.