pub struct InvertedBoundVar { /* private fields */ }Expand description
Like a BoundVar, but with the debrujin index inverted so as to create a canonical name we can use anywhere for each bound variable.
In BoundVar, the innermost bound variables have debrujin index 0, and
each further out BoundVar has a debrujin index 1 higher.
In InvertedBoundVar, the outermost variables have inverted_debrujin_idx 0,
and the innermost have their depth, not the other way around.