pub struct WriterState<I, DB, P = DB>{ /* private fields */ }Expand description
Writer state which persists across multiple writes.
Currently, this means keeping track of what IDs have been given what names, including deduplication information.
This data is stored using interior mutability - clones will point to the same underlying data.
Uses a separate type, P, for the database stored inside to account for
Arc or wrapping other storage mediums.
Implementations
Sourceimpl<I, DB, P> WriterState<I, DB, P>
impl<I, DB, P> WriterState<I, DB, P>