pub enum Guidance<I: Interner> {
    Definite(Canonical<Substitution<I>>),
    Suggested(Canonical<Substitution<I>>),
    Unknown,
}
When a goal holds ambiguously (e.g., because there are multiple possible solutions), we issue a set of guidance back to type inference.

Variants

Definite(Canonical<Substitution<I>>)

The existential variables must have the given values if the goal is ever to hold, but that alone isn’t enough to guarantee the goal will actually hold.

Suggested(Canonical<Substitution<I>>)

There are multiple plausible values for the existentials, but the ones here are suggested as the preferred choice heuristically. These should be used for inference fallback only.

Unknown

There’s no useful information to feed back to type inference