Struct chalk_solve::rust_ir::GeneratorInputOutputDatum
source · pub struct GeneratorInputOutputDatum<I: Interner> {
pub resume_type: Ty<I>,
pub yield_type: Ty<I>,
pub return_type: Ty<I>,
pub upvars: Vec<Ty<I>>,
}Expand description
The nested types for a generator. This always appears inside a GeneratorDatum
Fields
resume_type: Ty<I>The generator resume type - a value of this type is supplied by the caller when resuming the generator. Currently, this plays no rule in goal resolution.
yield_type: Ty<I>The generator yield type - a value of this type is supplied by the generator during a yield. Currently, this plays no role in goal resolution.
return_type: Ty<I>The generator return type - a value of this type is supplied by the generator when it returns. Currently, this plays no role in goal resolution
upvars: Vec<Ty<I>>The upvars stored by the generator. These represent types captured from the generator’s environment, and are stored across all yields. These types (along with the witness types) are considered ‘constituent types’ for the purposes of determining auto trait implementations - that its, a generator impls an auto trait A iff all of its constituent types implement A.